@@ -38,7 +38,7 @@ LOG = logging.getLogger(__name__)
 class OvnProviderDriver(driver_base.ProviderDriver):
 
     def __init__(self):
-        super(OvnProviderDriver, self).__init__()
+        super().__init__()
         self._ovn_helper = ovn_helper.OvnProviderHelper()
 
     def __del__(self):
@@ -58,6 +58,16 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                 user_fault_string=msg,
                 operator_fault_string=msg)
 
+    def _check_for_allowed_cidrs(self, allowed_cidrs):
+        # TODO(haleyb): add support for this
+        if isinstance(allowed_cidrs, o_datamodels.UnsetType):
+            allowed_cidrs = []
+        if allowed_cidrs:
+            msg = _('OVN provider does not support allowed_cidrs option')
+            raise driver_exceptions.UnsupportedOptionError(
+                user_fault_string=msg,
+                operator_fault_string=msg)
+
     def loadbalancer_create(self, loadbalancer):
         admin_state_up = loadbalancer.admin_state_up
         if isinstance(admin_state_up, o_datamodels.UnsetType):
@@ -138,12 +148,8 @@ class OvnProviderDriver(driver_base.ProviderDriver):
 
     def listener_create(self, listener):
         self._check_for_supported_protocols(listener.protocol)
-        # TODO(haleyb): add support for this
-        if not isinstance(listener.allowed_cidrs, o_datamodels.UnsetType):
-            msg = _('OVN provider does not support allowed_cidrs option')
-            raise driver_exceptions.UnsupportedOptionError(
-                user_fault_string=msg,
-                operator_fault_string=msg)
+        self._check_for_allowed_cidrs(listener.allowed_cidrs)
+
         admin_state_up = listener.admin_state_up
         if isinstance(admin_state_up, o_datamodels.UnsetType):
             admin_state_up = True
@@ -167,12 +173,7 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         self._ovn_helper.add_request(request)
 
     def listener_update(self, old_listener, new_listener):
-        # TODO(haleyb): add support for this
-        if not isinstance(new_listener.allowed_cidrs, o_datamodels.UnsetType):
-            msg = _('OVN provider does not support allowed_cidrs option')
-            raise driver_exceptions.UnsupportedOptionError(
-                user_fault_string=msg,
-                operator_fault_string=msg)
+        self._check_for_allowed_cidrs(new_listener.allowed_cidrs)
 
         request_info = {'id': new_listener.listener_id,
                         'loadbalancer_id': old_listener.loadbalancer_id,
@@ -279,7 +280,8 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                         'address': old_member.address,
                         'protocol_port': old_member.protocol_port,
                         'pool_id': old_member.pool_id,
-                        'subnet_id': old_member.subnet_id}
+                        'subnet_id': old_member.subnet_id,
+                        'old_admin_state_up': old_member.admin_state_up}
         if not isinstance(new_member.admin_state_up, o_datamodels.UnsetType):
             request_info['admin_state_up'] = new_member.admin_state_up
         request = {'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
@@ -291,7 +293,8 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         skipped_members = []
         pool_key, ovn_lb = self._ovn_helper._find_ovn_lb_by_pool_id(pool_id)
         external_ids = copy.deepcopy(ovn_lb.external_ids)
-        existing_members = external_ids[pool_key].split(',')
+        pool = external_ids[pool_key]
+        existing_members = pool.split(',') if pool else []
         members_to_delete = copy.copy(existing_members)
         for member in members:
             if (self._check_monitor_options(member) or
