@@ -300,6 +300,8 @@ class OvnProviderHelper(object):
             request_handler = self._lb_request_func_maps.get(request_type)
             try:
                 if request_handler:
+                    LOG.debug("Handling request %(req)s with info %(info)s",
+                              {'req': request_type, 'info': request['info']})
                     status = request_handler(request['info'])
                     if status:
                         self._update_status_to_octavia(status)
@@ -1470,9 +1472,31 @@ class OvnProviderHelper(object):
 
         external_ids[pool_key] = pool_data[pool_key]
         commands.extend(self._refresh_lb_vips(ovn_lb.uuid, external_ids))
+        subnet_id = member[constants.SUBNET_ID]
         commands.extend(
             self._update_lb_to_ls_association(
-                ovn_lb, subnet_id=member[constants.SUBNET_ID], associate=True))
+                ovn_lb, subnet_id=subnet_id, associate=True))
+
+        # Make sure that all logical switches related to logical router
+        # are associated with the load balancer. This is needed to handle
+        # potential race that happens when lrp and lb are created at the
+        # same time.
+        neutron_client = clients.get_neutron_client()
+        try:
+            subnet = neutron_client.show_subnet(subnet_id)
+            ls_name = utils.ovn_name(subnet['subnet']['network_id'])
+            ovn_ls = self.ovn_nbdb_api.ls_get(ls_name).execute(
+                check_error=True)
+            ovn_lr = self._find_lr_of_ls(ovn_ls)
+            if ovn_lr:
+                for net in self._find_ls_for_lr(ovn_lr):
+                    commands.append(self.ovn_nbdb_api.ls_lb_add(
+                        net, ovn_lb.uuid, may_exist=True))
+        except n_exc.NotFound:
+            pass
+        except idlutils.RowNotFound:
+            pass
+
         self._execute_commands(commands)
 
     def member_create(self, member):
