@@ -167,6 +167,10 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
         lbs = []
         for lb in self.nb_api.tables['Load_Balancer'].rows.values():
             external_ids = dict(lb.external_ids)
+            # Skip load balancers used by port forwarding plugin
+            if external_ids.get(ovn_const.OVN_DEVICE_OWNER_EXT_ID_KEY) == (
+                    ovn_const.PORT_FORWARDING_PLUGIN):
+                continue
             ls_refs = external_ids.get(ovn_const.LB_EXT_IDS_LS_REFS_KEY)
             if ls_refs:
                 external_ids[
@@ -572,10 +576,14 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
         lb_pools.append(m_pool)
         self._o_driver_lib.update_loadbalancer_status.reset_mock()
         self.ovn_driver.pool_create(m_pool)
+        operating_status = (
+            o_constants.ONLINE
+            if listener_id else o_constants.OFFLINE)
+
         expected_status = {
             'pools': [{'id': m_pool.pool_id,
                        'provisioning_status': 'ACTIVE',
-                       'operating_status': o_constants.OFFLINE}],
+                       'operating_status': operating_status}],
             'loadbalancers': [{'id': m_pool.loadbalancer_id,
                                'provisioning_status': 'ACTIVE'}]
         }
@@ -742,7 +750,7 @@ class TestOvnOctaviaBase(base.TestOVNFunctionalBase,
         pool = self._get_pool_from_lb_data(lb_data, pool_id=pool_id)
         expected_status = []
         self._o_driver_lib.update_loadbalancer_status.reset_mock()
-        self.ovn_driver.member_batch_update(members)
+        self.ovn_driver.member_batch_update(pool_id, members)
         for member in members:
             expected_status.append(
                 {'pools': [{'id': pool.pool_id,
