@@ -11,6 +11,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
+import copy
 from unittest import mock
 
 from octavia_lib.api.drivers import data_models
@@ -272,6 +273,7 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                 'protocol_port': self.ref_member.protocol_port,
                 'pool_id': self.ref_member.pool_id,
                 'admin_state_up': self.update_member.admin_state_up,
+                'old_admin_state_up': self.ref_member.admin_state_up,
                 'subnet_id': self.ref_member.subnet_id}
         expected_dict = {'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
                          'info': info}
@@ -285,39 +287,43 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         mock_ip_differs.assert_not_called()
 
     def test_member_batch_update(self):
-        self.driver.member_batch_update([self.ref_member, self.update_member])
+        self.driver.member_batch_update(self.pool_id,
+                                        [self.ref_member, self.update_member])
         self.assertEqual(self.mock_add_request.call_count, 3)
 
     def test_member_batch_update_no_members(self):
-        self.assertRaises(exceptions.UnsupportedOptionError,
-                          self.driver.member_batch_update, [])
-
-    def test_member_batch_update_missing_pool(self):
-        delattr(self.ref_member, 'pool_id')
-        self.assertRaises(exceptions.UnsupportedOptionError,
-                          self.driver.member_batch_update, [self.ref_member])
+        pool_key = 'pool_%s' % self.pool_id
+        ovn_lb = copy.copy(self.ovn_lb)
+        ovn_lb.external_ids[pool_key] = []
+        self.mock_find_lb_pool_key.return_value = ovn_lb
+        self.driver.member_batch_update(self.pool_id,
+                                        [self.ref_member, self.update_member])
+        self.assertEqual(self.mock_add_request.call_count, 2)
 
     def test_member_batch_update_skipped_monitor(self):
         self.ref_member.monitor_address = '10.11.1.1'
         self.assertRaises(exceptions.UnsupportedOptionError,
                           self.driver.member_batch_update,
+                          self.pool_id,
                           [self.ref_member])
 
     def test_member_batch_update_skipped_mixed_ip(self):
         self.ref_member.address = 'fc00::1'
         self.assertRaises(exceptions.UnsupportedOptionError,
                           self.driver.member_batch_update,
+                          self.pool_id,
                           [self.ref_member])
 
     def test_member_batch_update_unset_admin_state_up(self):
         self.ref_member.admin_state_up = data_models.UnsetType()
-        self.driver.member_batch_update([self.ref_member])
+        self.driver.member_batch_update(self.pool_id, [self.ref_member])
         self.assertEqual(self.mock_add_request.call_count, 2)
 
     def test_member_batch_update_missing_subnet_id(self):
         self.ref_member.subnet_id = None
         self.assertRaises(exceptions.UnsupportedOptionError,
-                          self.driver.member_batch_update, [self.ref_member])
+                          self.driver.member_batch_update,
+                          self.pool_id, [self.ref_member])
 
     def test_member_update_failure(self):
         self.assertRaises(exceptions.UnsupportedOptionError,
